@@ -8,8 +8,8 @@ get_grid_data <- function(x, autowidths, wrapping) {
     nr <- nrow_part(x, part)
     if (nr > 0) {
       data.frame(
-        col_id = rep(x$col_keys, each = nr),
-        ft_row_id = rep(seq_len(nr), length(x$col_keys)),
+        .col_id = rep(x$col_keys, each = nr),
+        .row_id = rep(seq_len(nr), length(x$col_keys)),
         stringsAsFactors = FALSE,
         check.names = FALSE
       )
@@ -17,27 +17,27 @@ get_grid_data <- function(x, autowidths, wrapping) {
   }), use.names = TRUE, idcol = ".part")
 
   grid_data$.part <- factor(grid_data$.part, levels = intersect(parts, grid_data$.part))
-  grid_data$col_id <- factor(grid_data$col_id, levels = x$col_keys)
-  keycols <- c(".part", "ft_row_id", "col_id")
+  grid_data$.col_id <- factor(grid_data$.col_id, levels = x$col_keys)
+  keycols <- c(".part", ".row_id", ".col_id")
   setorderv(grid_data, cols = keycols)
   grid_data[, c("row_index", "col_index") := list(
-    rleid(.SD$.part, .SD$ft_row_id), as.integer(.SD$col_id)
+    rleid(.SD$.part, .SD$.row_id), as.integer(.SD$.col_id)
   )]
   setorderv(grid_data, cols = c("row_index", "col_index"))
 
   # add column widths
   col_widths <- fortify_width(x)
   colnames(col_widths)[colnames(col_widths) == "width"] <- "col_width"
-  grid_data <- merge(grid_data, col_widths, by = c("col_id"))
+  grid_data <- merge(grid_data, col_widths, by = c(".col_id"))
 
   # add row heights
   row_heights <- fortify_height(x)
   colnames(row_heights)[colnames(row_heights) == "height"] <- "row_height"
-  grid_data <- merge(grid_data, row_heights, by = c(".part", "ft_row_id"))
+  grid_data <- merge(grid_data, row_heights, by = c(".part", ".row_id"))
 
   # add hrule
   row_hrules <- fortify_hrule(x)
-  grid_data <- merge(grid_data, row_hrules, by = c(".part", "ft_row_id"))
+  grid_data <- merge(grid_data, row_hrules, by = c(".part", ".row_id"))
 
   # calculate minimum and maximum cell height according to hrule
   grid_data[, "row_min_height" := fcase(
@@ -109,18 +109,28 @@ get_grid_data <- function(x, autowidths, wrapping) {
 
 
 grid_data_add_cell_info <- function(grid_data, x) {
-  keycols <- c(".part", "ft_row_id", "col_id")
+  keycols <- c(".part", ".row_id", ".col_id")
   spans <- fortify_span(x) # redondant avec get_grid_data, pas bien
   cell_data <- merge(
-    as.data.table(fortify_cells_properties(x)),
+    as.data.table(information_data_cell(x)),
     spans,
     by = keycols
   )
+
   fortify_borders_data <- fortify_latex_borders(cell_data)
+  # apply a correction to borders for vert. merged cells
+  last_bottom_borders_data <- fortify_borders_data[, list(
+    border.width.bottom = last(.SD$border.width.bottom),
+    border.color.bottom = last(.SD$border.color.bottom)
+  ), by = c(".part", ".col_id", "vspan_id")]
+  fortify_borders_data$border.width.bottom <- NULL
+  fortify_borders_data$border.color.bottom <- NULL
+  fortify_borders_data <- merge(fortify_borders_data, last_bottom_borders_data, by = c(".part", ".col_id", "vspan_id"))
+
   fortify_borders_data <- fortify_borders_data[
     , .SD,
     .SDcols = c(
-      ".part", "ft_row_id", "col_id", "border.color.top", "border.color.bottom",
+      ".part", ".row_id", ".col_id", "border.color.top", "border.color.bottom",
       "border.width.left", "border.color.left", "border.width.right",
       "border.color.right", "border.width.top", "border.width.bottom"
     )
@@ -140,6 +150,8 @@ grid_data_add_cell_info <- function(grid_data, x) {
 
   cell_data <- merge(cell_data, fortify_borders_data, by = keycols)
 
+  # browser()
+
   # merge with grid_data to keep only active cells
   cell_data <- merge(grid_data[, keycols, with = FALSE], cell_data, by = keycols)
 
@@ -222,10 +234,10 @@ grid_data_add_cell_info <- function(grid_data, x) {
 
 #' @importFrom grid unit
 grid_data_add_par_info <- function(grid_data, x) {
-  par_data <- fortify_paragraphs_properties(x)
+  par_data <- information_data_paragraph(x)
 
   # merge with grid_data to keep only active cells
-  keycols <- c(".part", "ft_row_id", "col_id")
+  keycols <- c(".part", ".row_id", ".col_id")
   par_data <- merge(grid_data[, c(
     keycols, "vertical.align", "angle"
   ), with = FALSE], par_data, by = keycols)
@@ -312,10 +324,10 @@ grid_data_add_par_info <- function(grid_data, x) {
 
 #' @importFrom grDevices is.raster
 grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
-  chunk_data <- fortify_run(x, expand_special_chars = FALSE)
+  chunk_data <- information_data_chunk(x, expand_special_chars = FALSE)
 
   # merge with grid_data to keep only active cells
-  keycols <- c(".part", "ft_row_id", "col_id")
+  keycols <- c(".part", ".row_id", ".col_id")
   chunk_data <- merge(
     grid_data[, c(keycols, "line_spacing", "angle"), with = FALSE],
     chunk_data,
@@ -329,7 +341,7 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
   chunk_data[, "is_text" := !.SD$is_raster & !.SD$is_equation]
 
   # avoid CMD check warnings
-  is_raster <- is_text <- txt <- is_tab <- is_newline <- is_space <-
+  is_raster <- is_text <- txt <- is_newline <- is_space <-
     is_superscript <- is_subscript <- angle <- NULL
 
   # remove empty text
@@ -381,15 +393,15 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
 
   # create chunk .part data (parts split by newline)
   part_data <- chunk_data[, c(
-    ".part", "ft_row_id", "col_id", "line_spacing", "angle",
+    ".part", ".row_id", ".col_id", "line_spacing", "angle",
     "font.family", "font.size", "italic", "bold",
     "txt", "is_text", "is_superscript", "is_subscript", "width", "height",
-    "seq_index", "chunk_index"
+    ".chunk_index", "chunk_index"
   ), with = FALSE]
   # expand by newline
   part_data <- expand_special_char(part_data, what = "\n", with = NA)
   # set part_index per chunk
-  setorderv(part_data, cols = c(keycols, "chunk_index", "seq_index"))
+  setorderv(part_data, cols = c(keycols, "chunk_index", ".chunk_index"))
   part_data[, "part_index" := 1:.N, by = c(keycols, "chunk_index")]
   setorderv(part_data, cols = c(keycols, "chunk_index", "part_index"))
   # calculate metrics
@@ -434,7 +446,7 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
     # create chunk word data (parts split by whitespace)
     word_data <- part_data
     word_data[, "wrapping" := fifelse(
-      .SD$is_text & !.SD$is_tab & !.SD$is_space & !.SD$is_newline &
+      .SD$is_text & !.SD$is_space & !.SD$is_newline &
         !.SD$is_superscript & !.SD$is_subscript, "whitespace", "none"
     )]
     # split by wrapping method
@@ -451,7 +463,7 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
     split_list <- NULL
 
     # set word_index and word_count per chunk part
-    setorderv(word_data, cols = c(keycols, "chunk_index", "part_index", "seq_index"))
+    setorderv(word_data, cols = c(keycols, "chunk_index", "part_index", ".chunk_index"))
     word_data[, c("word_index", "word_count") := list(1:.N, .N),
       by = c(keycols, "chunk_index", "part_index")
     ]
@@ -464,13 +476,13 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
     if (autowidths) {
       # don't take into account whitespace dimensions, except newline char in the beggining
       word_data[, "part_width" := fifelse(
-        .SD$is_newline & .SD$part_index > 1 | .SD$is_tab | .SD$is_space, 0, .SD$width
+        .SD$is_newline & .SD$part_index > 1 | .SD$is_space, 0, .SD$width
       )]
       word_data[, "part_ascent" := fifelse(
-        .SD$is_newline & .SD$part_index > 1 | .SD$is_tab | .SD$is_space, 0, .SD$ascent
+        .SD$is_newline & .SD$part_index > 1 | .SD$is_space, 0, .SD$ascent
       )]
       word_data[, "part_descent" := fifelse(
-        .SD$is_newline & .SD$part_index > 1 | .SD$is_tab | .SD$is_space, 0, .SD$descent
+        .SD$is_newline & .SD$part_index > 1 | .SD$is_space, 0, .SD$descent
       )]
 
       # calculate content metrics
@@ -517,14 +529,14 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
 
     # create chunk word data (parts split by any character)
     char_data <- word_data[
-      (is_text & !is_tab & !is_space & !is_newline & !is_superscript & !is_subscript), ,
+      (is_text & !is_space & !is_newline & !is_superscript & !is_subscript), ,
       drop = FALSE
     ]
     # expand by character
     char_data <- expand_special_char(char_data, what = ".", with = NA)
 
     # set word_index and word_count per chunk part
-    setorderv(char_data, cols = c(keycols, "chunk_index", "part_index", "word_index", "seq_index"))
+    setorderv(char_data, cols = c(keycols, "chunk_index", "part_index", "word_index", ".chunk_index"))
     char_data[, c("char_index", "char_count") := list(1:.N, .N),
       by = c(keycols, "chunk_index", "part_index", "word_index")
     ]
@@ -567,8 +579,8 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
     setorderv(part_data, cols = c(
       keycols, "chunk_index", "part_index", "word_index", "char_index"
     ))
-    # set seq_index unique for each cell
-    part_data[, "seq_index" := 1:.N, by = keycols]
+    # set .chunk_index unique for each cell
+    part_data[, ".chunk_index" := 1:.N, by = keycols]
 
     # set wrap child count
     part_data[, "child_count" := fcase(
@@ -591,16 +603,15 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
       by = c(keycols, "chunk_index")
     ]
   } else { # no wrapping
-    part_data[, "seq_index" := 1:.N, by = keycols]
+    part_data[, ".chunk_index" := 1:.N, by = keycols]
     part_data[, "child_count" := 0L]
     part_data[, "children_index" := integer(0)]
   }
-  setorderv(part_data, cols = c(keycols, "seq_index"))
+  setorderv(part_data, cols = c(keycols, ".chunk_index"))
 
   # replace special chars
   part_data[(is_newline), "txt" := ""]
   part_data[(is_space), "txt" := " "]
-  part_data[(is_tab), "txt" := "    "]
 
   # merge chunk data
   grid_data <- merge(
@@ -639,14 +650,14 @@ grid_data_add_chunk_info <- function(grid_data, x, autowidths, wrapping) {
       list(
         chunk_part_data = list(
           data.table(
-            seq_index = .SD$seq_index,
+            .chunk_index = .SD$.chunk_index,
             chunk_index = .SD$chunk_index,
             child_count = .SD$child_count,
             children_index = .SD$children_index,
             row_index = 0L,
             col_index = 0L,
             is_newline = .SD$is_newline,
-            is_whitespace = .SD$is_tab | .SD$is_space,
+            is_whitespace = .SD$is_space,
             width = .SD$width,
             height = .SD$height,
             ascent = .SD$ascent,
@@ -914,16 +925,14 @@ calc_grid_rotated_just <- function(just, angle) {
 #' @importFrom gdtools str_metrics
 calc_grid_text_metrics <- function(dat) {
   # avoid CMD check warnings
-  is_text <- is_tab <- is_newline <- is_space <- is_superscript <- is_subscript <- NULL
+  is_text <- is_newline <- is_space <- is_superscript <- is_subscript <- NULL
 
   # handle special chars
   dat[, "is_newline" := .SD$is_text & .SD$txt %in% "\n"]
-  dat[, "is_tab" := .SD$is_text & .SD$txt %in% "\t"]
+  dat[, "txt" := gsub("\t", "\u020\u020\u020\u020", .SD$txt)]
   dat[, "is_space" := .SD$is_text & .SD$txt %in% " "]
   # temporarily replace these, so that they get some height
   dat[(is_newline), "txt" := "."]
-  dat[(is_tab), "txt" := "mmmm"]
-  dat[(is_space), "txt" := "."]
 
   # calculate string metrics
   txt_metrics <- mapply(
@@ -947,8 +956,6 @@ calc_grid_text_metrics <- function(dat) {
   dat[(is_text), "height" := .SD$ascent + .SD$descent]
   dat[!(is_text), c("ascent", "descent") := list(.SD$height, 0)]
   dat[(is_newline), "txt" := "\n"]
-  dat[(is_tab), "txt" := "\t"]
-  dat[(is_space), "txt" := " "]
 
   # drop not needed columns
   dat[, c("part_width", "part_ascent", "part_descent") := NULL]
@@ -958,20 +965,20 @@ calc_grid_text_metrics <- function(dat) {
 }
 
 calc_grid_wrap_children <- function(dat) {
-  wrap_level <- seq_index <- NULL
+  wrap_level <- .chunk_index <- NULL
   mapply(
     function(level, index, child_count) {
       if (child_count > 0) {
         head(
-          dat[wrap_level == (level + 1) & seq_index > index, , drop = FALSE],
+          dat[wrap_level == (level + 1) & .chunk_index > index, , drop = FALSE],
           n = child_count
-        )$seq_index
+        )$.chunk_index
       } else {
         integer(0)
       }
     },
     dat$wrap_level,
-    dat$seq_index,
+    dat$.chunk_index,
     dat$child_count,
     SIMPLIFY = FALSE
   )
